@@ -999,6 +999,70 @@ pub fn einsum_merge_scalars(einsum: &Einsum) -> Option<Einsum> {
     Some(Einsum::try_new(new_args, einsum.out_axes.clone(), None).unwrap())
 }
 
+/// We want to turn einsum ab->b, where a is concat, to be Add [a1b->b, a2b->b...]
+/// This allows us to not realize all of ab at once to save memory.
+#[pyfunction]
+pub fn einsum_concat_to_add(einsum: &Einsum) -> Option<Add> {
+    // Which nodes contain a given einsum int, e.g. "ab,ab->" will produce {0: [0, 1], 1: [0, 1]}
+    let mut nodes_by_einsum_dim = HashMap::new();
+    for (concat_idx, (_circ, einsum_ints)) in einsum.args.iter().enumerate() {
+        for einsum_int in einsum_ints {
+            nodes_by_einsum_dim
+                .entry(einsum_int)
+                .or_insert(HashSet::new())
+                .insert(concat_idx);
+        }
+    }
+
+    let potential_concats_and_idx: Vec<(usize, &Concat)> = einsum
+        .args
+        .iter()
+        .enumerate()
+        .filter_map(|(concat_idx, (circ, in_axes))| {
+            if let Circuit::Concat(concat) = &***circ {
+                // `concat.axis` is in terms of this particular node, but we need the einsum dimension, so
+                // look it up, e.g. Einsum([0,1],[2,3] -> [0,3]), if the second input is a concat with
+                // concat.axis=1, needs to pull out 3.
+                let concat_dim = in_axes[concat.axis];
+                // If this axis appears multiple times in `in_axes`, we're doing the magic diagonal thing and this
+                // reduction won't work without more specialization.
+                if in_axes.iter().filter(|ax| **ax == concat_dim).count() > 1 {
+                    return None;
+                }
+                // If this input int appears in multiple nodes' input string, we can't use it
+                // TODO: Unless we get smarter and confirm the other nodes' concat shapes, or do some splitting, etc.
+                if nodes_by_einsum_dim[&concat_dim].len() > 1 {
+                    return None;
+                }
+                // This transformation only works if we're summing across the concat dimension.
+                if !einsum.out_axes.contains(&(concat_dim as u8)) {
+                    return Some((concat_idx, concat));
+                }
+            }
+            return None;
+        })
+        .collect();
+    if potential_concats_and_idx.len() == 0 {
+        return None;
+    }
+
+    // TODO: Maybe make this work across multiple Concat nodes in an Einsum.
+    let (concat_idx, concat_node) = potential_concats_and_idx[0];
+
+    let inner_einsum: Vec<CircuitRc> = concat_node
+        .nodes
+        .iter()
+        .map(|node| {
+            let mut new_args = einsum.args.clone();
+            // Replace the concatted `a` dimension with the partial `a` we're mapping over, then
+            // leave everything else in the output alone.
+            new_args[concat_idx] = (node.clone(), einsum.args[concat_idx].1.clone());
+            return Einsum::nrc(new_args, einsum.out_axes.clone(), None);
+        })
+        .collect();
+    return Some(Add::try_new(inner_einsum, None).unwrap());
+}
+
 #[pyfunction]
 pub fn index_split_axes(node: &Index, top_axes: std::collections::HashSet<usize>) -> Option<Index> {
     let mut bottom: Vec<TensorAxisIndex> = vec![];
@@ -1130,7 +1194,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     .count();
             if let Some(concat_indices) = concat_axis_indices_maybe {
                 if matches!(old_index_on_concat_axis, TensorAxisIndex::Single(_)) {
-                    let mut index = index_non_axis.clone();
+                    let mut index = index_non_axis;
                     for (i, ax) in concat_indices.iter().enumerate() {
                         if let Some(z) = ax {
                             index.0[inner.axis] = z.clone();
@@ -1148,7 +1212,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                             .filter_map(|(child, idx)| {
                                 idx.map(|idx| {
                                     let mut index = index_non_axis.clone();
-                                    index.0[inner.axis] = idx.clone();
+                                    index.0[inner.axis] = idx;
                                     Index::nrc(child.clone(), index, node.name_cloned())
                                 })
                             })
@@ -1531,13 +1595,13 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
 
     let mut reduced_any = 0;
 
-    let scalars_and_children: Vec<(Einsum, f64, Option<String>)> = add
-        .children()
-        .map(|c| match &**c {
-            Circuit::Einsum(e) => {
-                let mut scalar: f64 = 1.0;
-                let mut new_name: Option<String> = None;
-                let no_scalar_children: EinsumArgs = e
+    let scalars_and_children: Vec<(Einsum, f64, Option<String>)> =
+        add.children()
+            .map(|c| match &**c {
+                Circuit::Einsum(e) => {
+                    let mut scalar: f64 = 1.0;
+                    let mut new_name: Option<String> = None;
+                    let no_scalar_children: EinsumArgs = e
                     .args
                     .iter()
                     .filter(|args| {
@@ -1558,27 +1622,26 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
                         }else{
                             true
                         }
-                    })
-                    .map(|x| x.clone())
+                    }).cloned()
                     .collect();
 
-                (
-                    Einsum::try_new(no_scalar_children, e.out_axes.clone(), e.name_cloned())
-                        .unwrap(),
-                    scalar,
-                    new_name,
-                )
-            }
-            Circuit::ScalarConstant(s) => {
-                if s.info().shape.len() == 0 {
-                    (Einsum::empty(None), s.value, s.name_cloned())
-                } else {
-                    (Einsum::identity(c, None), 1.0, None)
+                    (
+                        Einsum::try_new(no_scalar_children, e.out_axes.clone(), e.name_cloned())
+                            .unwrap(),
+                        scalar,
+                        new_name,
+                    )
                 }
-            }
-            _ => (Einsum::identity(c, None), 1.0, None),
-        })
-        .collect();
+                Circuit::ScalarConstant(s) => {
+                    if s.info().shape.len() == 0 {
+                        (Einsum::empty(None), s.value, s.name_cloned())
+                    } else {
+                        (Einsum::identity(c, None), 1.0, None)
+                    }
+                }
+                _ => (Einsum::identity(c, None), 1.0, None),
+            })
+            .collect();
 
     if reduced_any <= 1 {
         return None;
@@ -1612,5 +1675,5 @@ pub fn add_fuse_scalar_multiples(add: &Add) -> Option<Add> {
         })
         .collect();
 
-    return Some(Add::try_new(nodes, add.name_cloned()).unwrap());
+    Some(Add::try_new(nodes, add.name_cloned()).unwrap())
 }
