@@ -257,7 +257,7 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
     // for unknown reasons, maybe i'll investigate
     let circuit = timed!(
         apply_fn_until_same(&circuit, |x| deep_push_down_index(
-            compiler_simp(&x, context),
+            compiler_simp(x, context),
             None
         )),
         10,
@@ -301,7 +301,7 @@ pub fn optimize_to_schedule(
     circuit: CircuitRc,
     settings: OptimizationSettings,
 ) -> Result<Schedule, SchedulingError> {
-    let mut context = &mut OptimizationContext::new_settings_circuit(settings, circuit.clone());
+    let context = &mut OptimizationContext::new_settings_circuit(settings, circuit.clone());
     let verbose = settings.verbose;
     if verbose > 0 {
         println!("Optimizing verbose {}", verbose)
@@ -312,7 +312,7 @@ pub fn optimize_to_schedule(
             rust_expression_notation_circuit(circuit.clone(), true)
         );
     }
-    let optimized_circuit = timed!(optimize_circuit(circuit, &mut context), 10, verbose >= 1);
+    let optimized_circuit = timed!(optimize_circuit(circuit, context), 10, verbose >= 1);
     // return evaluate_fn(&*optimized_circuit).unwrap();
     let schedule = if settings.scheduling_naive {
         circuit_to_schedule_naive_toposort(optimized_circuit)
