@@ -87,8 +87,7 @@ static GENERAL_FUNCTIONS_SPECS: GILLazyPy<HashMap<String, GeneralFunctionSpec>>
         ])
     });
 
-pub static OFFICIAL_GENERALFUNCTION_INVERSES: [(&'static str, &'static str); 1] =
-    [("reciprocal", "reciprocal")];
+pub static OFFICIAL_GENERALFUNCTION_INVERSES: [(&str, &str); 1] = [("reciprocal", "reciprocal")];
 
 /// GeneralFunctionSpec contains all needed info about function, and is the same on all instances with the same function
 /// how batchability works: input_batchability is a mask indicating which inputs support batching. if none do, there is no batching.
