@@ -1,16 +1,14 @@
 use super::generalfunction::OFFICIAL_GENERALFUNCTION_INVERSES;
-use super::{evaluate_fn, evaluate_fn_dtype_device, CircuitNode, ScalarConstant};
+use super::{evaluate_fn_dtype_device, CircuitNode, ScalarConstant};
 
-use crate::all_imports::{TorchDeviceDtype, TorchDeviceDtypeOp};
+use crate::all_imports::TorchDeviceDtypeOp;
 use crate::circuit::{Circuit, CircuitRc, GeneralFunction};
 use crate::{pyo3_prelude::*, sv};
 
 #[pyfunction]
 pub fn generalfunction_merge_inverses(circuit: &GeneralFunction) -> Option<CircuitRc> {
-    if circuit.nodes.len()==1 && circuit.spec.is_official && let Circuit::GeneralFunction(inner)=&**circuit.nodes[0] && inner.spec.is_official{
-        if let Some(_)=OFFICIAL_GENERALFUNCTION_INVERSES.iter().position(|(a,b)|*a==&circuit.spec.name&&*b==&inner.spec.name){
-            return Some(inner.nodes[0].clone())
-        }
+    if circuit.nodes.len()==1 && circuit.spec.is_official && let Circuit::GeneralFunction(inner)=&**circuit.nodes[0] && inner.spec.is_official && OFFICIAL_GENERALFUNCTION_INVERSES.iter().any(|(a,b)|*a==&circuit.spec.name&&*b==&inner.spec.name) {
+        return Some(inner.nodes[0].clone())
     }
     None
 }
