@@ -1116,8 +1116,8 @@ where
     toposorted.reverse(); // its children first by default
 
     let mut parents: HashMap<CircuitRc, Vec<CircuitRc>> = HashMap::new();
-    for (i, sub) in toposorted.into_iter().enumerate() {
-        f(&sub, &parents.get(&sub).unwrap_or(&vec![]));
+    for (_i, sub) in toposorted.into_iter().enumerate() {
+        f(&sub, parents.get(&sub).unwrap_or(&vec![]));
         for child in sub.children() {
             parents.entry(child).or_insert(vec![]).push(sub.clone());
         }
@@ -1132,8 +1132,8 @@ where
     toposorted.reverse(); // its children first by default
 
     let mut parents: HashMap<CircuitRc, Vec<CircuitRc>> = HashMap::new();
-    for (i, sub) in toposorted.into_iter().enumerate() {
-        f(&sub, &parents.get(&sub).unwrap_or(&vec![]))?;
+    for (_i, sub) in toposorted.into_iter().enumerate() {
+        f(&sub, parents.get(&sub).unwrap_or(&vec![]))?;
         for child in sub.children() {
             parents.entry(child).or_insert(vec![]).push(sub.clone());
         }
