@@ -1,20 +1,17 @@
 use crate::all_imports::{TensorAxisIndex, TensorIndex};
 use crate::circuit::deep_map_fallible_pre_new_children;
-use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
+use crate::hashmaps::FxHashMap as HashMap;
 
-use crate::util::dict_to_list;
 use crate::{pycall, pyo3_prelude::*, sv};
-use once_cell::sync::{Lazy, OnceCell};
+use once_cell::sync::Lazy;
 use regex::Regex;
 use std::iter::zip;
-use std::sync::Mutex;
 
 use super::circuit_manipulation::replace_nodes;
-use super::circuit_utils::has_leaf_symbols;
+
 use super::{
-    deep_map_op_context, deep_map_op_context_preorder_stoppable, deep_map_op_pre_new_children,
-    deep_map_unwrap, deep_map_unwrap_preorder, prelude::*, visit_circuit, Add, CachedCircuitInfo,
-    CircResult, Concat, GeneralFunction, HashBytes, Index, Rearrange, Scatter,
+    deep_map_op_context, deep_map_op_context_preorder_stoppable, deep_map_unwrap, prelude::*, Add,
+    CachedCircuitInfo, CircResult, Concat, GeneralFunction, HashBytes, Index, Rearrange, Scatter,
 };
 
 use crate::{
@@ -23,7 +20,6 @@ use crate::{
     tensor_util::{Shape, TorchDeviceDtype},
 };
 
-use cached::lazy_static::lazy_static;
 use macro_rules_attribute::apply;
 use pyo3::types::PyDict;
 
@@ -64,7 +60,7 @@ pub fn expand_node(circuit: &Circuit, inputs: &Vec<CircuitRc>) -> CircResult {
             let new_spec = node
                 .spec
                 .conform_to_input_shape(&input_shape_non_batch, true)
-                .map_err(|e| CircuitConstructionError::RearrangeWrongInputShape {
+                .map_err(|_e| CircuitConstructionError::RearrangeWrongInputShape {
                     spec: node.spec.clone(),
                     shape: input_shape_non_batch.clone(),
                 })?
@@ -164,7 +160,7 @@ pub fn expand_node(circuit: &Circuit, inputs: &Vec<CircuitRc>) -> CircResult {
             for bs in &batch_shapes {
                 if !bs.is_empty() {
                     if let Some(existing) = batch_shape {
-                        if *bs != &existing[..] {
+                        if *bs != existing {
                             return Err(CircuitConstructionError::InconsistentBatches {
                                 batch_shapes: batch_shapes
                                     .iter()
@@ -180,7 +176,7 @@ pub fn expand_node(circuit: &Circuit, inputs: &Vec<CircuitRc>) -> CircResult {
             }
             let next_axis = node.next_axis();
             let newies = || (next_axis as u8..next_axis + batch_shape.unwrap().len() as u8);
-            let out_axes = if let Some(bs) = batch_shape {
+            let out_axes = if let Some(_bs) = batch_shape {
                 newies().chain(node.out_axes.iter().cloned()).collect()
             } else {
                 node.out_axes.clone()
@@ -189,7 +185,7 @@ pub fn expand_node(circuit: &Circuit, inputs: &Vec<CircuitRc>) -> CircResult {
                 node.args
                     .iter()
                     .enumerate()
-                    .map(|(i, (child, ints))| {
+                    .map(|(i, (_child, ints))| {
                         (inputs[i].clone(), {
                             if !batch_shapes[i].is_empty() {
                                 newies().chain(ints.iter().cloned()).collect()
@@ -213,7 +209,7 @@ pub fn expand_node(circuit: &Circuit, inputs: &Vec<CircuitRc>) -> CircResult {
                 Ok(circuit.clone().rc())
             } else {
                 Err(CircuitConstructionError::ExpandNodeUnknownVariant {
-                    variant: circuit.variant_string().to_owned(),
+                    variant: circuit.variant_string(),
                 })
             }
         }
@@ -245,12 +241,12 @@ where
     let recursor = |circuit: &Circuit,
                     new_children: &Vec<CircuitRc>|
      -> Result<CircuitRc, CircuitConstructionError> {
-        if let Some(replaced) = replacer(&circuit) {
+        if let Some(replaced) = replacer(circuit) {
             return Ok(replaced);
         }
         expand_node(circuit, new_children)
     };
-    deep_map_fallible_pre_new_children(&**circuit, recursor)
+    deep_map_fallible_pre_new_children(&circuit, recursor)
 }
 
 #[pyclass(unsendable)]
@@ -322,15 +318,10 @@ impl ModuleNodeSpec {
             }
         }
         replace_expand_bottom_up(self.spec_circuit.clone(), |c| {
-            if let Some(i) = self
-                .input_specs
+            self.input_specs
                 .iter()
                 .position(|x| &x.symbol.clone().c() == c)
-            {
-                Some(nodes[i].clone())
-            } else {
-                None
-            }
+                .map(|i| nodes[i].clone())
         })
     }
 
@@ -520,7 +511,7 @@ impl ModuleNodeSpec {
     pub fn resize(&self, shapes: Vec<Shape>) -> Result<Self, CircuitConstructionError> {
         let input_specs: Vec<ModuleNodeArgSpec> = zip(&self.input_specs, shapes)
             .map(|(spec, shape)| ModuleNodeArgSpec {
-                symbol: Symbol::new(shape, spec.symbol.uuid.clone(), spec.symbol.name_cloned()),
+                symbol: Symbol::new(shape, spec.symbol.uuid, spec.symbol.name_cloned()),
                 batchable: spec.batchable,
                 expandable: spec.expandable,
             })
@@ -594,8 +585,8 @@ impl ModuleNode {
         };
         out.info.shape = shape;
         out.name = out.auto_name(name);
-        let out = out.init_info();
-        out
+
+        out.init_info()
     }
 
     pub fn new_kwargs(
@@ -672,7 +663,7 @@ impl CircuitNode for ModuleNode {
 
     fn eval_tensors(
         &self,
-        tensors: &[crate::py_types::Tensor],
+        _tensors: &[crate::py_types::Tensor],
         _device_dtype: &TorchDeviceDtype,
     ) -> Result<crate::py_types::Tensor, super::TensorEvalError> {
         unimplemented!();
@@ -741,7 +732,7 @@ impl ModuleNode {
 #[pyfunction]
 pub fn inline_all_modules(circuit: CircuitRc) -> CircuitRc {
     deep_map_unwrap(&circuit, |c| match c {
-        Circuit::ModuleNode(mn) => inline_all_modules(mn.expand().clone()),
+        Circuit::ModuleNode(mn) => inline_all_modules(mn.expand()),
         _ => c.clone().rc(),
     })
 }
