@@ -75,7 +75,7 @@ pub fn parse_compiler_repr_bijection(
                             .get(4)
                             .ok_or_else(rf)?
                             .as_str()
-                            .split(",")
+                            .split(',')
                             .map(|z| z.trim())
                             .filter(|z| !z.is_empty())
                             .map(|x| x.parse::<usize>())
@@ -158,7 +158,7 @@ pub fn parse_compiler_repr_bijection(
                 ps.name.clone(),
             )),
             "Add" => {
-                if ps.extra != "" {
+                if !ps.extra.is_empty() {
                     Err(CircuitConstructionError::ParsingExtraUnneededString {
                         string: ps.extra.to_owned(),
                     })
@@ -176,8 +176,9 @@ pub fn parse_compiler_repr_bijection(
                 ps.name.clone(),
             )
             .map(|z| z.rc()),
-            "Einsum" => Einsum::from_einsum_string(&ps.extra, children.clone(), ps.name.clone())
-                .map(|z| z.rc()),
+            "Einsum" => {
+                Einsum::from_einsum_string(&ps.extra, children, ps.name.clone()).map(|z| z.rc())
+            }
             "Rearrange" => {
                 Rearrange::from_einops_string(children[0].clone(), &ps.extra, ps.name.clone())
                     .map(|z| z.rc())
@@ -205,7 +206,7 @@ pub fn parse_compiler_repr_bijection(
                 }
             }
             "GeneralFunction" => {
-                GeneralFunction::new_by_name(children.clone(), ps.extra.clone(), ps.name.clone())
+                GeneralFunction::new_by_name(children, ps.extra.clone(), ps.name.clone())
                     .map(|z| z.rc())
             }
             "Index" => Index::try_new(
@@ -227,7 +228,7 @@ pub fn parse_compiler_repr_bijection(
             )
             .map(|z| z.rc()),
             "ModuleNode" => ModuleNode::try_new(
-                children.clone(),
+                children,
                 module_spec_map
                     .get(&ps.extra.clone())
                     .cloned()
@@ -254,7 +255,7 @@ pub fn parse_compiler_repr_bijection(
     }
     let mut context: HashMap<usize, CircuitRc> = HashMap::new();
     deep_convert_partial_circ(
-        stack[0].clone(),
+        stack[0],
         &partial_circuits,
         &mut context,
         &module_spec_map,
