@@ -44,7 +44,7 @@ pub fn repr_circuit_deep_compiler(
             result.push(' ');
             if bijection {
                 result.push('\'');
-                result.push_str(&n.replace(r"\", r"\\").replace("'", r"\'"));
+                result.push_str(&n.replace('\\', r"\\").replace('\'', r"\'"));
                 result.push('\'');
             } else {
                 result.push_str(n);
@@ -101,7 +101,7 @@ pub fn repr_circuit_deep_compiler(
                     }
                 }
                 Circuit::ModuleNode(mn) => {
-                    format!("{}", &mn.spec.name.as_ref().unwrap_or(&"".to_owned()))
+                    (&mn.spec.name.as_ref().unwrap_or(&"".to_owned())).to_string()
                 }
                 Circuit::ArrayConstant(ac) => {
                     if bijection {
