@@ -1,7 +1,6 @@
 use crate::{
     hashmaps::{AHashSet as HashSet, FxHashMap as HashMap},
     py_types::{scalar_to_tensor, tensor_scale, un_flat_concat, PY_UTILS},
-    timed_value,
 };
 use std::fmt::{self, Display};
 
@@ -22,7 +21,7 @@ use super::{
     print::oom_fmt,
     scheduling_z3::schedule_dag_strategy_ints,
     visit_circuit, Add, ArrayConstant, HashBytes, IrreducibleNode, Leaf, ModuleNodeSpec,
-    PyHashBytes, ScalarConstant, Symbol,
+    ScalarConstant, Symbol,
 };
 use crate::pyo3_prelude::*;
 use crate::util::filter_to_idx;
@@ -114,7 +113,7 @@ impl Schedule {
             } else {
                 evaluate_schedule(self)[&self.output_circuit.as_ref().unwrap().0].clone()
             };
-            if self.device_dtype.device != "cpu".to_owned() {
+            if self.device_dtype.device != *"cpu" {
                 Python::with_gil(|py| {
                     PY_UTILS
                         .torch
@@ -178,7 +177,7 @@ impl Schedule {
             .keys()
             .chain(self.scalar_constants.keys())
             .chain(self.instructions.iter().filter_map(|ins| match ins {
-                Instruction::Compute(k, c) => Some(k),
+                Instruction::Compute(k, _c) => Some(k),
                 _ => None,
             }))
             .max()
@@ -223,7 +222,7 @@ impl Display for Schedule {
                 .join(" "),
             self.scalar_constants
                 .iter()
-                .map(|(k, c)| k.to_string())
+                .map(|(k, _c)| k.to_string())
                 .collect::<Vec<String>>()
                 .join(" "),
         )
@@ -340,13 +339,13 @@ pub fn evaluate_schedule(schedule: &Schedule) -> HashMap<usize, Tensor> {
             Instruction::Compute(key, circ) => {
                 let child_keys: Vec<usize> = circ.children().map(get_child_key).collect();
                 child_keys.iter().for_each(|child_key| {
-                    if !live.contains_key(&child_key) {
+                    if !live.contains_key(child_key) {
                         panic!("FAIL");
                     }
                 });
                 let tensors: Vec<Tensor> = child_keys
                     .iter()
-                    .map(|child_key| live[&child_key].clone())
+                    .map(|child_key| live[child_key].clone())
                     .collect();
                 let result_err = circ.eval_tensors(&tensors, &schedule.device_dtype);
                 if result_err.is_err() {
@@ -558,7 +557,7 @@ pub fn order_to_schedule(
         for child in ex.children() {
             let next_id = circ_to_id.len();
             let dep = *circ_to_id.entry(child.info().hash).or_insert(next_id);
-            if !Leaf::matches(&**child)
+            if !Leaf::matches(&child)
                 && seen_dependencies.insert(dep)
                 && !to_keep.contains(&child.info().hash)
             {
@@ -693,10 +692,8 @@ pub fn circuits_to_dag(circuits: &[&Circuit]) -> Dag {
             // ArrayConstants are never added to the dag to begin with because they're always 0 cost
             if !Leaf::matches(c) {
                 let my_number = number_node(c, &mut result);
-                let children_to_consider: Vec<CircuitRc> = c
-                    .children()
-                    .filter(|child| !Leaf::matches(&***child))
-                    .collect();
+                let children_to_consider: Vec<CircuitRc> =
+                    c.children().filter(|child| !Leaf::matches(child)).collect();
                 result.children[my_number] = children_to_consider
                     .iter()
                     .map(|child| number_node(child, &mut result))
@@ -910,7 +907,7 @@ pub fn scheduled_evaluate(
 ) -> Result<Tensor, SchedulingError> {
     let schedule = circuit_to_schedule(
         circuit.clone(),
-        &mut OptimizationContext::new_settings_circuit(settings, circuit.clone()),
+        &mut OptimizationContext::new_settings_circuit(settings, circuit),
     )?;
     Ok(evaluate_schedule(&schedule)[&schedule.output_circuit.unwrap().0].clone())
 }
@@ -936,12 +933,12 @@ fn replace_module_schedules(schedule: &Schedule, context: &mut OptimizationConte
     let mut scalar_to_id: HashMap<ScalarConstant, usize> = schedule
         .scalar_constants
         .iter()
-        .map(|(a, b)| (b.clone(), a.clone()))
+        .map(|(a, b)| (b.clone(), *a))
         .collect();
     let mut irreducible_to_id: HashMap<IrreducibleNode, usize> = schedule
         .constants
         .iter()
-        .map(|(a, b)| (b.clone(), a.clone()))
+        .map(|(a, b)| (b.clone(), *a))
         .collect();
     result.instructions = vec![];
     let mut next_key = schedule.next_key();
@@ -1002,7 +999,7 @@ fn replace_module_schedules(schedule: &Schedule, context: &mut OptimizationConte
                                 Instruction::Drop(drop) => {
                                     result
                                         .instructions
-                                        .push(Instruction::Drop(inner_to_outer_key[&drop]));
+                                        .push(Instruction::Drop(inner_to_outer_key[drop]));
                                 }
                                 Instruction::Compute(inner_k, c) => {
                                     let new_c = c
@@ -1018,7 +1015,7 @@ fn replace_module_schedules(schedule: &Schedule, context: &mut OptimizationConte
                                         })
                                         .rc();
                                     let key = inner_to_outer_key
-                                        .get(&inner_k)
+                                        .get(inner_k)
                                         .cloned()
                                         .unwrap_or_else(|| {
                                             inner_to_outer_key.insert(*inner_k, next_key);
