@@ -154,7 +154,7 @@ pub fn schedule_dag_strategy_ints(
         .collect();
     let outputs = dag.get_outputs();
     let zero = Int::from_u64(ctx_ref, 0);
-    let one = Int::from_u64(ctx_ref, 1);
+    let _one = Int::from_u64(ctx_ref, 1);
     let time_end = Int::from_u64(ctx_ref, (n_time_slots - 1) as u64);
     let end_times: Vec<Int> = (0..dag.node_costs.len())
         .map(|i| {
