@@ -63,9 +63,9 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
         add_collapse_scalar_inputs, add_deduplicate, add_elim_zeros, add_flatten_once,
         add_fuse_scalar_multiples, add_make_broadcasts_explicit, add_pull_removable_axes,
         concat_elim_identity, concat_merge_uniform, concat_pull_removable_axes,
-        concat_repeat_to_rearrange, distribute, distribute_all, einsum_elim_identity,
-        einsum_elim_zero, einsum_flatten_once, einsum_merge_scalars, einsum_nest_path,
-        einsum_of_permute_merge, einsum_pull_removable_axes, extract_add,
+        concat_repeat_to_rearrange, distribute, distribute_all, einsum_concat_to_add,
+        einsum_elim_identity, einsum_elim_zero, einsum_flatten_once, einsum_merge_scalars,
+        einsum_nest_path, einsum_of_permute_merge, einsum_pull_removable_axes, extract_add,
         generalfunction_pull_removable_axes, index_elim_identity, index_fuse, index_merge_scalar,
         index_split_axes, permute_of_einsum_merge, push_down_index, rearrange_elim_identity,
         rearrange_fuse, rearrange_merge_scalar, remove_add_few_input,
@@ -249,6 +249,7 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(toposort_circuit, m)?)?;
     m.add_function(wrap_pyfunction!(add_pull_diags, m)?)?;
     m.add_function(wrap_pyfunction!(einsum_push_down_trace, m)?)?;
+    m.add_function(wrap_pyfunction!(einsum_concat_to_add, m)?)?;
     m.add_function(wrap_pyfunction!(concat_repeat_to_rearrange, m)?)?;
     m.add_function(wrap_pyfunction!(extract_add, m)?)?;
     m.add_function(wrap_pyfunction!(add_fuse_scalar_multiples, m)?)?;
