@@ -353,7 +353,7 @@ impl EinsumSpec {
                         .split_whitespace()
                         .map(|x| {
                             let l = string_to_int.len() as u8;
-                            string_to_int.entry(x).or_insert(l).clone()
+                            *string_to_int.entry(x).or_insert(l)
                         })
                         .collect()
                 })
@@ -362,7 +362,7 @@ impl EinsumSpec {
                 .split_whitespace()
                 .map(|x| {
                     let l = string_to_int.len() as u8;
-                    string_to_int.entry(x).or_insert(l).clone()
+                    *string_to_int.entry(x).or_insert(l)
                 })
                 .collect();
             (input_ints, output_ints)
